@@ -4,7 +4,7 @@ Author  : Ajith Kumar B.P, bpajith@gmail.com
 License : GNU GPL version 3
 '''
 
-import eyes, sys, time, math
+import sys, time, math
 from numpy import *
 import numpy.fft
 from scipy import optimize 
@@ -71,14 +71,17 @@ def fit_sine(xlist,ylist, freq = 0):	# Time in mS, V in volts, freq in Hz
 	#print 'guess a & freq = ', amp, freq
 	par = [abs(amp), freq*0.001, 0.0, 0.0] # Amp, freq, phase , offset
 	plsq = leastsq(sine_erf, par,args=(ya,xa))
+	if plsq[0][0] < 0:
+		par = [abs(amp), freq*0.001, 3.14, 0.0] # Amp, freq, phase , offset
+		plsq = leastsq(sine_erf, par,args=(ya,xa))
 	if plsq[1] > 4:
 		return None
 	yfit = sine_eval(xa, plsq[0])
-	if plsq[0][0] < 0:
-		#print plsq[0]
-		plsq[0][0] *= -1
-		plsq[0][2] += pi
-		#print plsq[0]
+	#if plsq[0][0] < 0:
+	    #print plsq[0]
+	    #plsq[0][0] *= -1
+	    #plsq[0][2] += pi
+	    #print plsq[0]
 	return yfit,plsq[0]
 
 #--------------------------Damped Sine Fit ------------------------------------------------
